import React, { useState } from 'react';
import { Link, useNavigate, useParams } from 'react-router-dom';
import SvgIcon from '../../components/SvgIcon';

export default function ChatSidebar({ chatHistory, onDeleteChat }) {
    const navigate = useNavigate();
    const { chatId } = useParams();
    const [activeDropdown, setActiveDropdown] = useState(null);

    const handleNewChat = () => {
        navigate('/chat');
    };

    const handleMouseEnter = (id) => {
        setActiveDropdown(id);
    };

    const handleMouseLeave = () => {
        setActiveDropdown(null);
    };

    const handleDeleteChat = (e, id) => {
        e.preventDefault();
        e.stopPropagation();
        if (onDeleteChat) {
            onDeleteChat(id);
        }
        setActiveDropdown(null);
    };

    return (
        <div className='chat-sidebar d-flex flex-column h-100'>
            <div className='p-3 pb-0'>
                <h5 className='mb-0'>Chats</h5>
            </div>

            <div className='p-3'>
                <button
                    className='btn btn-dark w-100 d-flex align-items-center justify-content-center gap-2'
                    onClick={handleNewChat}
                >
                    <SvgIcon className='plus' color='#ffffff' />
                    <span>New Chat</span>
                </button>
            </div>

            <div className='overflow-auto flex-grow-1'>
                <ul className='list-group list-group-flush'>
                    {chatHistory.map((chat) => (
                        <li
                            key={chat.id}
                            className={`list-group-item border-0 position-relative ${
                                chatId === chat.id ? 'bg-light' : ''
                            }`}
                        >
                            <Link
                                to={`/chat/${chat.knowledgeBaseId}/${chat.id}`}
                                className={`text-decoration-none d-flex align-items-center gap-2 py-2  text-dark ${
                                    chatId === chat.id ? 'fw-bold' : ''
                                }`}
                            >
                                <div className='text-truncate'>{chat.title}</div>
                            </Link>
                            <div
                                className='dropdown-hover-area position-absolute end-0 top-0 bottom-0'
                                style={{ width: '40px' }}
                                onMouseEnter={() => handleMouseEnter(chat.id)}
                                onMouseLeave={handleMouseLeave}
                            >
                                <button className='btn btn-sm position-absolute end-0 top-50 translate-middle-y me-2'>
                                    <SvgIcon className='more-dot' width='5' height='16' />
                                </button>
                                {activeDropdown === chat.id && (
                                    <div
                                        className='position-absolute end-0 top-100 bg-white shadow rounded p-1 z-3'
                                        style={{ zIndex: 1000, minWidth: '80px' }}
                                    >
                                        <button
                                            className='btn btn-sm text-danger d-flex align-items-center gap-2 w-100'
                                            onClick={(e) => handleDeleteChat(e, chat.id)}
                                        >
                                            <SvgIcon className='trash' />
                                            <span>删除</span>
                                        </button>
                                    </div>
                                )}
                            </div>
                        </li>
                    ))}
                </ul>
            </div>
        </div>
    );
}
