import React from 'react';
import SvgIcon from '../../../../components/SvgIcon';

/**
 * 文档列表组件
 */
const DocumentList = ({ documents, selectedDocuments, onSelectAll, onSelectDocument, onDeleteDocument, selectAll }) => {
    if (documents.length === 0) {
        return <div className='alert alert-warning'>暂无数据集，请上传数据集</div>;
    }

    return (
        <div className='table-responsive'>
            <table className='table table-hover'>
                <thead className='table-light'>
                    <tr>
                        <th scope='col' width='40'>
                            <div className='form-check'>
                                <input
                                    className='form-check-input'
                                    type='checkbox'
                                    checked={selectAll}
                                    onChange={onSelectAll}
                                />
                            </div>
                        </th>
                        <th scope='col'>名称</th>
                        <th scope='col'>描述</th>
                        <th scope='col'>大小</th>
                        <th scope='col'>更新时间</th>
                        <th scope='col' width='100'>
                            操作
                        </th>
                    </tr>
                </thead>
                <tbody>
                    {documents.map((doc) => (
                        <tr key={doc.id}>
                            <td>
                                <div className='form-check'>
                                    <input
                                        className='form-check-input'
                                        type='checkbox'
                                        checked={selectedDocuments.includes(doc.id)}
                                        onChange={() => onSelectDocument(doc.id)}
                                    />
                                </div>
                            </td>
                            <td>{doc.name}</td>
                            <td>{doc.description}</td>
                            <td>{doc.size}</td>
                            <td>{new Date(doc.update_time).toLocaleDateString()}</td>
                            <td>
                                <div className='d-flex gap-1'>
                                    <button
                                        className='btn btn-sm text-danger'
                                        title='删除'
                                        onClick={() => onDeleteDocument(doc.id)}
                                    >
                                        <SvgIcon className='trash' width='16' height='16' />
                                    </button>
                                </div>
                            </td>
                        </tr>
                    ))}
                </tbody>
            </table>
        </div>
    );
};

export default DocumentList;
