import React from 'react';
import KnowledgeCard from '../KnowledgeCard';

/**
 * 知识库列表组件
 */
const KnowledgeBaseList = ({ knowledgeBases, isSearching, onCardClick, onRequestAccess }) => {
    if (knowledgeBases.length === 0) {
        return (
            <div className='alert alert-warning'>
                {isSearching ? '没有找到匹配的知识库' : '暂无知识库，请创建新的知识库'}
            </div>
        );
    }

    return (
        <div className='row gap-3 m-0'>
            {knowledgeBases.map((item) => (
                <React.Fragment key={item.id}>
                    <KnowledgeCard
                        id={item.id}
                        title={item.name}
                        description={item.desc}
                        documents={item.document_count || 0}
                        date={new Date(item.create_time).toLocaleDateString()}
                        access={item.permissions.can_edit ? 'full' : item.permissions.can_read ? 'read' : 'none'}
                        onClick={() => onCardClick(item.id)}
                        onRequestAccess={onRequestAccess}
                    />
                </React.Fragment>
            ))}
        </div>
    );
};

export default KnowledgeBaseList;
