import React, { Suspense } from 'react';
import { Navigate, Route, Routes } from 'react-router-dom';
import Mainlayout from '../layouts/Mainlayout';
import KnowledgeBase from '../pages/KnowledgeBase/KnowledgeBase';
import KnowledgeBaseDetail from '../pages/KnowledgeBase/KnowledgeBaseDetail';
import Chat from '../pages/Chat/Chat';
import Loading from '../components/Loading';
import Login from '../pages/Auth/Login';
import Signup from '../pages/Auth/Signup';
import ProtectedRoute from './protectedRoute';
import { useSelector } from 'react-redux';

function AppRouter() {
    const { user } = useSelector((state) => state.auth);

    return (
        <Suspense fallback={<Loading />}>
            <Routes>
                <Route element={<ProtectedRoute />}>
                    <Route
                        path='/'
                        element={
                            <Mainlayout>
                                <KnowledgeBase />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/knowledge-base/:id'
                        element={
                            <Mainlayout>
                                <KnowledgeBaseDetail />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/knowledge-base/:id/:tab'
                        element={
                            <Mainlayout>
                                <KnowledgeBaseDetail />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/chat'
                        element={
                            <Mainlayout>
                                <Chat />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/chat/:knowledgeBaseId'
                        element={
                            <Mainlayout>
                                <Chat />
                            </Mainlayout>
                        }
                    />
                    <Route
                        path='/chat/:knowledgeBaseId/:chatId'
                        element={
                            <Mainlayout>
                                <Chat />
                            </Mainlayout>
                        }
                    />
                </Route>
                <Route path='/login' element={<Login />} />
                <Route path='/signup' element={<Signup />} />
                <Route path='*' element={<Navigate to={!!user ? '/' : '/login'} replace />} />
            </Routes>
        </Suspense>
    );
}
export default AppRouter;
